BODY {
	FONT-SIZE: 9pt; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #FFFFFF
}
TD, TH {
	FONT-SIZE: 9pt; FONT-FAMILY: MS Sans Serif
}
.bgr0 {
	FONT-SIZE: 9pt; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #ffffff
}
.bgr1 {
	FONT-SIZE: 9pt; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #FFFFFF
}
.bgr2 {
	FONT-SIZE: 9pt; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #293869
}
.bgr3 {
	FONT-SIZE: 9pt; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #aab3d1
}
.bgr4 {
	FONT-SIZE: 9pt; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #efefef
}
.bgr5 {
	FONT-SIZE: 9pt; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #dededc
}
.bgr7 {
	FONT-SIZE: 9pt; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #b0b0b0
}
.bgr9 {
	FONT-SIZE: 9pt; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #dde5ef
}
.bgr13 {
	FONT-SIZE: 9pt; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #ffe0e0
}
.bgr10 {
	BACKGROUND-COLOR: #424142
}
.outter {
	BORDER-RIGHT: #ffffff 1px solid; BORDER-TOP: #2d2d2d 1px solid; BORDER-LEFT: #2d2d2d 1px solid; BORDER-BOTTOM: #ffffff 1px solid; HEIGHT: 100%
}
.serv {
	BORDER-RIGHT: #2d2d2d 1px solid; BORDER-TOP: #ffffff 1px solid; BORDER-LEFT: #ffffff 1px solid; BORDER-BOTTOM: #2d2d2d 1px solid; BACKGROUND-COLOR: #d0cfcf
}
.inner {
	BORDER-RIGHT: #ffffff 1px solid; BORDER-TOP: #2d2d2d 1px solid; BORDER-LEFT: #2d2d2d 1px solid; WIDTH: 100%; BORDER-BOTTOM: #ffffff 1px solid; HEIGHT: 100%
}
.color0 {
	FONT-SIZE: 9pt; COLOR: #ffffff; FONT-FAMILY: MS Sans Serif
}
.color1 {
	FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif
}
.color2 {
	FONT-SIZE: 9pt; COLOR: #5e5e5e; FONT-FAMILY: MS Sans Serif
}
.color3 {
	FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif
}
.color4 {
	FONT-SIZE: 9pt; COLOR: #ab300f; FONT-FAMILY: MS Sans Serif
}
.header0 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #ffffff; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #5f7452
}
.header1 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #ffffff; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #293869
}
.header2 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #ffffff; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #888888
}
.header3 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #ffffff; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #b0b0b0
}
.header4 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #ffffff
}
.header5 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #efefef
}
.header6 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #dededc
}
.header7 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #ffffff
}
.header8 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #efefef
}
.header9 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #dededc
}
.header10 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #ab300f; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #ffffff
}
.header11 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #ab300f; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #efefef
}
.header12 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #ab300f; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #dededc
}
.header13 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #ab300f; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #888888
}
.header14 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #ab300f; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #b0b0b0
}
.txt0 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #ffffff; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #5f7452
}
.txt1 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #ffffff; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #293869
}
.txt2 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #ffffff; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #888888
}
.txt3 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #ffffff; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #b0b0b0
}
.txt4 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #ffffff
}
.txt5 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #efefef
}
.txt6 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #dededc
}
.txt8 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #efefef
}
.txt9 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #dededc
}
.txt10 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #c8c8c8; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #ffffff
}
.txt11 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #ffffff
}
.txt12 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #ab300f; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #efefef
}
.txt13 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #ab300f; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #ffffff
}
A {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #b0b0b0; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A:link {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #b0b0b0; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A:active {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #b0b0b0; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A:hover {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #b0b0b0; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A:visited {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #b0b0b0; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk0 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk0:link {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk0:active {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk0:hover {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk0:visited {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk1 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #596084; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk1:link {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #596084; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk1:active {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #596084; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk1:hover {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #596084; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk1:visited {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #596084; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk2 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #0073bd; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk2:link {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #0073bd; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk2:active {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #0073bd; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk2:hover {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #0073bd; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk2:visited {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #0073bd; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk3 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #ffffff; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk3:link {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #ffffff; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk3:active {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #ffffff; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk3:hover {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #ffffff; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk3:visited {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #ffffff; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk4 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #0076bd; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk4:link {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #0076bd; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk4:active {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #0076bd; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk4:hover {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #0076bd; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk4:visited {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #0076bd; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk5 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk5:link {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk5:active {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk5:hover {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk5:visited {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk6 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk6:link {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk6:active {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk6:hover {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk6:visited {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk7 {
	FONT-WEIGHT: normal; FONT-SIZE: 10px; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk7:link {
	FONT-WEIGHT: normal; FONT-SIZE: 10px; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk7:active {
	FONT-WEIGHT: normal; FONT-SIZE: 10px; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk7:visited {
	FONT-WEIGHT: normal; FONT-SIZE: 10px; COLOR: #5e5e5e; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk7:hover {
	FONT-WEIGHT: normal; FONT-SIZE: 10px; COLOR: #5e5e5e; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk8 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #ab300f; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk8:link {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #ab300f; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk8:active {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #ab300f; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk8:hover {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #ab300f; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk8:visited {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #ab300f; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk9 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #ab300f; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk9:link {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #ab300f; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk9:active {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #ab300f; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk9:hover {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #ab300f; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk9:visited {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #ab300f; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk10 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk10:link {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk10:active {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk10:hover {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk10:visited {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk11 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk11:link {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk11:active {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk11:hover {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk11:active {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk11:visited {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #909090; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk12 {
	FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk12:link {
	FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk12:active {
	FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk12:hover {
	FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk12:visited {
	FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk13 {
	FONT-WEIGHT: normal; FONT-SIZE: 10px; COLOR: #ff0000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk13:link {
	FONT-WEIGHT: normal; FONT-SIZE: 10px; COLOR: #ff0000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk13:active {
	FONT-WEIGHT: normal; FONT-SIZE: 10px; COLOR: #ff0000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk13:hover {
	FONT-WEIGHT: normal; FONT-SIZE: 10px; COLOR: #ff0000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk13:active {
	FONT-WEIGHT: normal; FONT-SIZE: 10px; COLOR: #ff0000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk13:visited {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #ffffff; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk14 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #415d8c; FONT-STYLE: italic; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk14:link {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #415d8c; FONT-STYLE: italic; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk14:active {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #415d8c; FONT-STYLE: italic; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk14:hover {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #415d8c; FONT-STYLE: italic; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk14:visited {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #415d8c; FONT-STYLE: italic; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk15 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #909090; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk15:link {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #909090; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk15:active {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #909090; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk15:hover {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #909090; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk15:visited {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #909090; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk16 {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #909090; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk16:link {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #909090; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk16:active {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #909090; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk16:hover {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #909090; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk16:visited {
	FONT-WEIGHT: bold; FONT-SIZE: 9pt; COLOR: #909090; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk17 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk17:link {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk17:active {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk17:hover {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk17:visited {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk18 {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-STYLE: italic; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk18:link {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-STYLE: italic; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk18:active {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-STYLE: italic; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk18:hover {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-STYLE: italic; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
A.lnk18:visited {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-STYLE: italic; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}
INPUT {
	FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif
}
SELECT {
	FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif
}
OPTION {
	FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif
}
TEXTAREA {
	FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif
}
td.row-cell {
	border: 1px solid #888888;
}
th.row-cell-header {
	border-top: 1px solid #888888;
	border-left: 1px solid #888888;
}
.row-cell {
	FONT-FAMILY: Arial; 
	FONT-WEIGHT: normal; 
	FONT-SIZE: 10pt; 
	COLOR: #676767; 
	BACKGROUND-COLOR: #ffffff;
	padding-top: 3px;
	padding-bottom: 2px;
}
.row-cell-no-scroll {
	FONT-FAMILY: Arial; 
	FONT-WEIGHT: normal; 
	FONT-SIZE: 10pt; 
	COLOR: #676767; 
	BACKGROUND-COLOR: #ffffff;
	padding-top: 3px;
	padding-bottom: 2px;

	position: relative;
	left: expression(this.parentElement.parentElement.parentElement.parentElement.scrollLeft);

}
.row-cell-transparent {
	FONT-FAMILY: Arial; 
	FONT-WEIGHT: normal; 
	FONT-SIZE: 10pt; 
	COLOR: #000000; 
	padding-top: 3px;
	padding-bottom: 2px;
}
.row-cell-transparent-no-scroll {
	FONT-FAMILY: Arial; 
	FONT-WEIGHT: normal; 
	FONT-SIZE: 10pt; 
	COLOR: #000000; 
	padding-top: 3px;
	padding-bottom: 2px;

	position: relative;
	left: expression(this.parentElement.parentElement.parentElement.parentElement.scrollLeft);

}
.row-button {
	FONT-FAMILY: Arial; 
	FONT-WEIGHT: normal; 
	FONT-SIZE: 10pt; 
	COLOR: #000000; 
	BACKGROUND-COLOR: #ffffff;
	padding-top: 3px;
	padding-bottom: 2px;
}
.row-cell-total {
	FONT-FAMILY: Arial; 
	FONT-WEIGHT: bold;   
	FONT-SIZE: 10pt; 
	COLOR: #000000; 
	BACKGROUND-COLOR: #efefef;
	padding-top: 5px;
	padding-bottom: 5px;
}
.row-cell-total-no-scroll {
	FONT-FAMILY: Arial; 
	FONT-WEIGHT: bold;   
	FONT-SIZE: 10pt; 
	COLOR: #000000; 
	BACKGROUND-COLOR: #efefef;
	padding-top: 5px;
	padding-bottom: 5px;

	position: relative;
	left: expression(this.parentElement.parentElement.parentElement.parentElement.scrollLeft);

}
.row-cell-header {
	FONT-FAMILY: Arial; 
	FONT-WEIGHT: bold;   
	FONT-SIZE: 10pt; 
	COLOR: #000000; 
	BACKGROUND-COLOR: #efefef;
	padding-top: 3px;
	padding-bottom: 2px;
	
/*
	border-top:solid 1px #D6D3CE;
	border-bottom:solid 1px #D6D3CE;
*/

	position: relative;
	top: expression(this.parentElement.parentElement.parentElement.parentElement.scrollTop);

}

.row-cell-header-no-scroll {
	FONT-FAMILY: Arial; 
	FONT-WEIGHT: bold;   
	FONT-SIZE: 10pt; 
	COLOR: #000000; 
	BACKGROUND-COLOR: #efefef;
	padding-top: 3px;
	padding-bottom: 2px;
	
/*
	border-top:solid 1px #D6D3CE;
	border-bottom:solid 1px #D6D3CE;
*/

	position: relative;
	top: expression(this.parentElement.parentElement.parentElement.parentElement.scrollTop);
	left: expression(this.parentElement.parentElement.parentElement.parentElement.scrollLeft);

}


/*
.row-cell-hilite {
	FONT-FAMILY: Arial; 
	FONT-SIZE: 10pt; 
	COLOR: #000000; 
	BACKGROUND-COLOR: #dededc;
	padding-top: 3px;
	padding-bottom: 2px;
}
*/

.row-cell-hilite {
	BACKGROUND-COLOR: #dededc;
}

.row-cell-hilite-no-scroll {
	BACKGROUND-COLOR: #dededc;

	position: relative;
	left: expression(this.parentElement.parentElement.parentElement.parentElement.scrollLeft);

}


A.row-cell, A.row-cell:link, A.row-cell:active, A.row-cell:hover, A.row-cell:visited {
	FONT-FAMILY: Arial; 
	FONT-SIZE: 10pt; 
	COLOR: #293869; 
	TEXT-DECORATION: none;
	BACKGROUND-COLOR: transparent;
}
A.row-button, A.row-button:link, A.row-button:active, A.row-button:hover, A.row-button:visited {
	FONT-FAMILY: Arial; 
	FONT-SIZE: 10pt; 
	COLOR: #000000; 
	TEXT-DECORATION: none;
	BACKGROUND-COLOR: transparent;
}
checkbox.row-cell,
	padding: 1px;
	BACKGROUND-COLOR: transparent;
}



td.vert-menu {
	BACKGROUND-COLOR: #b9d4e5;
	font-weight: normal; 
	font-size: 8pt; 
	color: black; 
	font-family: MS Sans Serif; 
	text-decoration: none;
	padding-top:4px;
	padding-bottom:4px;
}

td.main-menu {
	BACKGROUND-COLOR: #D6D3CE;
	padding-top:1px;
	padding-bottom:1px;
	border-width:1px;
	border-style:solid;
	border-color:#D6D3CE;
}
a.main-menu, a.main-menu:link, a.main-menu:active, a.main-menu:visited, a.main-menu:hover {
	font-family: MS Sans Serif;
	font-weight: bold; 
	font-size: 8pt; 
	color: #0163a3; 
	text-decoration: none;
}


td.button {
	BACKGROUND-COLOR: #b9d4e5;
	padding-top:0px;
	padding-bottom:0px;
	padding-left:3px;
	padding-right:3px;
	border-width:1px;
	border-style:solid;
	border-color:#D6D3CE;
}
A.button, A.button:link, A.button:active, A.button:hover, A.button:visited {
	FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #000000; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none
}


.bgr28 {
	BACKGROUND-COLOR: #b9d4e5;
}}


td.tabs-0 {
	BACKGROUND-COLOR: #D6D3CE;
	padding-top:0px;
	padding-bottom:0px;
}
td.tabs-1 {
	BACKGROUND-COLOR: #FFFFFF;
	padding-top:0px;
	padding-bottom:0px;
}
a.tabs, a.tabs:link, a.tabs:active, a.tabs:visited, a.tabs:hover {
	font-family: MS Sans Serif; 
	font-size: 8pt; 
	color: #000000; 
	text-decoration: none;
}

A.path, A.path:link, A.path:active, A.path:hover, A.path:visited {
	FONT-WEIGHT: normal; 
	FONT-SIZE: 8pt; 
/*	
	COLOR: #000000; 
*/	
	COLOR: #596084; 
	FONT-FAMILY: MS Sans Serif; 
	TEXT-DECORATION: none;
}























.form-deleted-label {
	FONT-WEIGHT: bold; 
	FONT-SIZE: 10pt; 
	FONT-FAMILY: Arial; 
	COLOR: #000000; 
	BACKGROUND-COLOR: #dadae0;
	padding-left: 10px;
	padding-right: 10px;
	padding-top: 5px;
	padding-bottom: 5px;
}
.form-deleted-inputs {
	FONT-SIZE: 10pt; 
	FONT-FAMILY: Arial; 
	BACKGROUND-COLOR: #dadae0;
	padding-left: 5px;
	padding-right: 10px;
}
A.form-deleted-inputs, A.form-deleted-inputs:link, A.form-deleted-inputs:hover, A.form-deleted-inputs:visited {
	FONT-WEIGHT: normal; 
	FONT-SIZE: 10pt; 
	FONT-FAMILY: Arial; 
	BACKGROUND-COLOR: #dadae0;
	COLOR: #293869; 
	TEXT-DECORATION: none;
	padding-left: 0px;
	padding-right: 0px;
}






.form-passive-label {
	FONT-WEIGHT: bold; 
	FONT-SIZE: 10pt; 
	FONT-FAMILY: Arial; 
	COLOR: #000000; 
	BACKGROUND-COLOR: #fafaff;
	padding-left: 10px;
	padding-right: 10px;
	padding-top: 5px;
	padding-bottom: 5px;
}
.form-passive-inputs {
	FONT-SIZE: 10pt; 
	FONT-FAMILY: Arial; 
	BACKGROUND-COLOR: #fafaff;
	padding-left: 5px;
	padding-right: 10px;
}
A.form-passive-inputs, A.form-passive-inputs:link, A.form-passive-inputs:hover, A.form-passive-inputs:visited {
	FONT-WEIGHT: normal; 
	FONT-SIZE: 10pt; 
	FONT-FAMILY: Arial; 
	COLOR: #293869; 
	TEXT-DECORATION: none;
	padding-left: 0px;
	padding-right: 0px;
}


.form-active-label {
	FONT-WEIGHT: bold; 
	FONT-SIZE: 10pt; 
	FONT-FAMILY: Arial; 
	COLOR: #000000; 
	BACKGROUND-COLOR: #efefef;
	padding-left: 10px;
	padding-right: 10px;
	padding-top: 5px;
	padding-bottom: 5px;
}
.form-active-inputs {
	FONT-SIZE: 10pt; 
	FONT-FAMILY: Arial; 
	BACKGROUND-COLOR: #efefef;
	padding-left: 5px;
	padding-right: 10px;
}

A.form-active-inputs, A.form-active-inputs:link, A.form-active-inputs:hover, A.form-active-inputs:visited {
	FONT-WEIGHT: normal; 
	FONT-SIZE: 10pt; 
	FONT-FAMILY: Arial; 
	COLOR: #293869; 
	TEXT-DECORATION: none;
	padding-left: 0px;
	padding-right: 0px;
}

.form-active-ellipsis {
	FONT-SIZE: 9pt; 
	FONT-FAMILY: Arial; 
	BACKGROUND-COLOR: #ffffff;
}

input.form-active-inputs, select.form-active-inputs, textarea.form-active-inputs {
	FONT-SIZE: 10pt; 
	FONT-FAMILY: Arial; 
	BACKGROUND-COLOR: #ffffff;
	border-color: #dededc;
	padding-left: 1px;
}




div.table-container {

      	PADDING-RIGHT: 0px;
      	OVERFLOW-Y: auto;
      	PADDING-LEFT: 0px;
      	OVERFLOW-X: auto;
      	PADDING-BOTTOM: 0px;
      	MARGIN: 0px;
      	WIDTH: expression(document.body.offsetWidth - (window.name == 'application_frame' ? 12 : 17));
      	PADDING-TOP: 0px;      	
      	
	scrollbar-base-color:#d6d3ce;
	scrollbar-arrow-color:#485f70;
	scrollbar-3dlight-color: #efefef;
	scrollbar-darkshadow-color:#b0b0b0;

}

div.table-container-x {

      	PADDING-RIGHT: 0px;
      	OVERFLOW-Y: visible;
      	PADDING-LEFT: 0px;
      	OVERFLOW-X: auto;
      	PADDING-BOTTOM: 0px;
      	MARGIN: 0px;
      	WIDTH: expression(document.body.offsetWidth - (window.name == 'application_frame' ? 12 : 17));
      	PADDING-TOP: 0px;      	
      	
	scrollbar-base-color:#d6d3ce;
	scrollbar-arrow-color:#485f70;
	scrollbar-3dlight-color: #efefef;
	scrollbar-darkshadow-color:#b0b0b0;

}

div.checkboxes {

      	OVERFLOW: auto;
      	
	scrollbar-base-color:#d6d3ce;
	scrollbar-arrow-color:#485f70;
	scrollbar-3dlight-color: #efefef;
	scrollbar-darkshadow-color:#b0b0b0;

}








TD.tabs-0 {padding-top: 10px; background-image: url(/i/_skins/GazOil/tab_b_0.gif); background-position: bottom;}
TD.tabs-1 {padding-top: 10px; background-image: url(/i/_skins/GazOil/tab_b_1.gif); background-position: bottom}

.bgr6 {FONT-SIZE: 9pt; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #b9d4e5;}
.bgr8 {FONT-SIZE: 9pt; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #FFFFFF;}
.bgr18 {FONT-SIZE: 9pt; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #eaeaea;}
.bgr18 TD.button {border-width: 0px; PADDING-RIGHT: 3px; PADDING-LEFT: 3px; PADDING-BOTTOM: 0px; PADDING-TOP: 0px; BACKGROUND-COLOR: #eaeaea;}

/*.header15 {FONT-SIZE: 14pt; COLOR: #333333; FONT-FAMILY: Arial, MS Sans Serif; BACKGROUND-COLOR: #C8D0B1; padding: 3px 0 5px 0;} */

.header15 {
	FONT-SIZE: 14pt; COLOR: #0163a3; FONT-FAMILY: Arial, MS Sans Serif; BACKGROUND-COLOR: #d5d5d5; padding: 3px 0 5px 0;
}

/* 
	.row-cell-header {FONT-SIZE: 10pt; PADDING: 15px 0 15px 0; COLOR: #333333; FONT-FAMILY: Arial; POSITION: relative; ; TOP: expression(this.parentElement.parentElement.parentElement.parentElement.scrollTop); BACKGROUND-COLOR: #F7F7F7; background-image: url(/i/_skins/GazOil/row-cell-header_bgr.gif); background-position: bottom; background-repeat: repeat-x;}
*/
.row-cell-header-black {FONT-WEIGHT: bold; FONT-SIZE: 9pt; PADDING: 15px 0 15px 0; COLOR: #0076bd; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none; POSITION: relative; ; TOP: expression(this.parentElement.parentElement.parentElement.parentElement.scrollTop); BACKGROUND-COLOR: #F7F7F7; background-image: url(/i/_skins/GazOil/row-cell-header_bgr.gif); background-position: bottom; background-repeat: repeat-x;}
.row-cell-header {FONT-WEIGHT: bold; FONT-SIZE: 9pt; PADDING: 15px 0 15px 0; COLOR: #2935a7; FONT-FAMILY: MS Sans Serif; TEXT-DECORATION: none; POSITION: relative; ; TOP: expression(this.parentElement.parentElement.parentElement.parentElement.scrollTop); BACKGROUND-COLOR: #F7F7F7; background-image: url(/i/_skins/GazOil/row-cell-header_bgr.gif); background-position: bottom; background-repeat: repeat-x;}


.txt7 {FONT-WEIGHT: normal; FONT-SIZE: 9pt; COLOR: #293869; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #ffffff;}

TD.main-menu {padding: 9px 3px 9px 3px; BORDER-RIGHT: #d5e5ef 1px solid; BORDER-TOP: #b9d4e5 1px solid; BORDER-LEFT: #d5e5ef 0px solid; BORDER-BOTTOM: #b9d4e5 1px solid; BACKGROUND-COLOR: #b9d4e5;}
TD.vert-menu {cursor: hand; FONT-WEIGHT: normal; FONT-SIZE: 8pt; PADDING-BOTTOM: 4px; COLOR: black; PADDING-TOP: 4px; FONT-FAMILY: MS Sans Serif; BACKGROUND-COLOR: #b9d4e5; TEXT-DECORATION: none}

A.row-cell {
	FONT-SIZE: 10pt; COLOR: #333333; FONT-FAMILY: Arial; BACKGROUND-COLOR: transparent; TEXT-DECORATION: none
}

A.row-cell:link {
	FONT-SIZE: 10pt; COLOR: #333333; FONT-FAMILY: Arial; BACKGROUND-COLOR: transparent; TEXT-DECORATION: none
}
A.row-cell:active {
	FONT-SIZE: 10pt; COLOR: #333333; FONT-FAMILY: Arial; BACKGROUND-COLOR: transparent; TEXT-DECORATION: none
}
A.row-cell:hover {
	FONT-SIZE: 10pt; COLOR: #333333; FONT-FAMILY: Arial; BACKGROUND-COLOR: transparent; TEXT-DECORATION: none
}
A.row-cell:visited {
	FONT-SIZE: 10pt; COLOR: #333333; FONT-FAMILY: Arial; BACKGROUND-COLOR: transparent; TEXT-DECORATION: none
}


A.row-cell-branch {
	FONT-SIZE: 11pt; FONT-WEIGHT: bold;  COLOR: #333333; FONT-FAMILY: Arial; BACKGROUND-COLOR: transparent; TEXT-DECORATION: none
}
A.row-cell-branch:link {
	FONT-SIZE: 11pt; FONT-WEIGHT: bold;  COLOR: #333333; FONT-FAMILY: Arial; BACKGROUND-COLOR: transparent; TEXT-DECORATION: none
}
A.row-cell-branch:active {
	FONT-SIZE: 11pt; FONT-WEIGHT: bold;  COLOR: #333333; FONT-FAMILY: Arial; BACKGROUND-COLOR: transparent; TEXT-DECORATION: none
}
A.row-cell-branch:hover {
	FONT-SIZE: 11pt; FONT-WEIGHT: bold;  COLOR: #333333; FONT-FAMILY: Arial; BACKGROUND-COLOR: transparent; TEXT-DECORATION: none
}
A.row-cell-branch:visited {
	FONT-SIZE: 11pt; FONT-WEIGHT: bold;  COLOR: #333333; FONT-FAMILY: Arial; BACKGROUND-COLOR: transparent; TEXT-DECORATION: none
}

A.row-cell-blue {
	FONT-SIZE: 11pt; FONT-WEIGHT: bold;  COLOR: #4152f3; FONT-FAMILY: Arial; BACKGROUND-COLOR: transparent; TEXT-DECORATION: none
}
A.row-cell-blue:link {
	FONT-SIZE: 11pt; FONT-WEIGHT: bold;  COLOR: #4152f3; FONT-FAMILY: Arial; BACKGROUND-COLOR: transparent; TEXT-DECORATION: none
}
A.row-cell-blue:active {
	FONT-SIZE: 11pt; FONT-WEIGHT: bold;  COLOR: #4152f3; FONT-FAMILY: Arial; BACKGROUND-COLOR: transparent; TEXT-DECORATION: none
}
A.row-cell-blue:hover {
	FONT-SIZE: 11pt; FONT-WEIGHT: bold;  COLOR: #4152f3; FONT-FAMILY: Arial; BACKGROUND-COLOR: transparent; TEXT-DECORATION: none
}
A.row-cell-blue:visited {
	FONT-SIZE: 11pt; FONT-WEIGHT: bold;  COLOR: #4152f3; FONT-FAMILY: Arial; BACKGROUND-COLOR: transparent; TEXT-DECORATION: none
}


TD.tab-active {background-image: url(/i/_skins/GazOil/tab_b_1.gif);}
TD.tab-inactive {background-image: url(/i/_skins/GazOil/tab_b_0.gif);}
.bgr-tabs-0 {BACKGROUND-COLOR: #C8D0B1;}
.bgr-tabs-0 A, .bgr-tabs-0 A.path {COLOR: #333333;}
.bgr-tabs-0 A.path {TEXT-DECORATION: underline;}
.toolbar {BACKGROUND-COLOR: #FFFFFF; background-image: url(/i/images/header.gif); background-repeat: no-repeat;}
.toolbar A, .toolbar TD A {COLOR: #333333;}
.toolbar TD.button {BORDER-RIGHT: #E6EAD9 1px solid; PADDING-RIGHT: 3px; BORDER-TOP: #E6EAD9 1px solid; PADDING-LEFT: 3px; PADDING-BOTTOM: 0px; BORDER-LEFT: #E6EAD9 1px solid; PADDING-TOP: 0px; BORDER-BOTTOM: #E6EAD9 1px solid; BACKGROUND-COLOR: #E6EAD9;}
.toolbar TD.bgr6, .toolbar TD.bgr8 {BACKGROUND-COLOR: #b9d4e5;}
DIV.hr-green {BACKGROUND-COLOR: #D5DDC0; height: 2px; margin: 10px 0 0 15px;}




/* Calendar styles */


/* The main calendar widget.  DIV containing a table. */

.calendar {
  position: relative;
  display: none;
  border-top: 2px solid #fff;
  border-right: 2px solid #000;
  border-bottom: 2px solid #000;
  border-left: 2px solid #fff;
  font-size: 11px;
  color: #000;
  cursor: default;
  background: #d4d0c8;
  font-family: tahoma,verdana,sans-serif;
}

.calendar table {
  border-top: 1px solid #000;
  border-right: 1px solid #fff;
  border-bottom: 1px solid #fff;
  border-left: 1px solid #000;
  font-size: 11px;
  color: #000;
  cursor: default;
  background: #d4d0c8;
  font-family: tahoma,verdana,sans-serif;
}

/* Header part -- contains navigation buttons and day names. */

.calendar .button { /* "<<", "<", ">", ">>" buttons have this class */
  text-align: center;
  padding: 1px;
  border-top: 1px solid #fff;
  border-right: 1px solid #000;
  border-bottom: 1px solid #000;
  border-left: 1px solid #fff;
}

.calendar .nav {
  background: transparent url(menuarrow.gif) no-repeat 100% 100%;
}

.calendar thead .title { /* This holds the current "month, year" */
  font-weight: bold;
  padding: 1px;
  border: 1px solid #000;
  background: #848078;
  color: #fff;
  text-align: center;
}

.calendar thead .headrow { /* Row <TR> containing navigation buttons */
}

.calendar thead .daynames { /* Row <TR> containing the day names */
}

.calendar thead .name { /* Cells <TD> containing the day names */
  border-bottom: 1px solid #000;
  padding: 2px;
  text-align: center;
  background: #f4f0e8;
}

.calendar thead .weekend { /* How a weekend day name shows in header */
  color: #f00;
}

.calendar thead .hilite { /* How do the buttons in header appear when hover */
  border-top: 2px solid #fff;
  border-right: 2px solid #000;
  border-bottom: 2px solid #000;
  border-left: 2px solid #fff;
  padding: 0px;
  BACKGROUND-COLOR: #e4e0d8;
}

.calendar thead .active { /* Active (pressed) buttons in header */
  padding: 2px 0px 0px 2px;
  border-top: 1px solid #000;
  border-right: 1px solid #fff;
  border-bottom: 1px solid #fff;
  border-left: 1px solid #000;
  BACKGROUND-COLOR: #c4c0b8;
}

/* The body part -- contains all the days in month. */

.calendar tbody .day { /* Cells <TD> containing month days dates */
  width: 2em;
  text-align: right;
  padding: 2px 4px 2px 2px;
}

.calendar table .wn {
  padding: 2px 3px 2px 2px;
  border-right: 1px solid #000;
  background: #f4f0e8;
}

.calendar tbody .rowhilite td {
  background: #e4e0d8;
}

.calendar tbody .rowhilite td.wn {
  background: #d4d0c8;
}

.calendar tbody td.hilite { /* Hovered cells <TD> */
  padding: 1px 3px 1px 1px;
  border-top: 1px solid #fff;
  border-right: 1px solid #000;
  border-bottom: 1px solid #000;
  border-left: 1px solid #fff;
}

.calendar tbody td.active { /* Active (pressed) cells <TD> */
  padding: 2px 2px 0px 2px;
  border-top: 1px solid #000;
  border-right: 1px solid #fff;
  border-bottom: 1px solid #fff;
  border-left: 1px solid #000;
}

.calendar tbody td.selected { /* Cell showing selected date */
  font-weight: bold;
  border-top: 1px solid #000;
  border-right: 1px solid #fff;
  border-bottom: 1px solid #fff;
  border-left: 1px solid #000;
  padding: 2px 2px 0px 2px;
  background: #e4e0d8;
}

.calendar tbody td.weekend { /* Cells showing weekend days */
  color: #f00;
}

.calendar tbody td.today { /* Cell showing today date */
  font-weight: bold;
  color: #00f;
}

.calendar tbody .disabled { color: #999; }

.calendar tbody .emptycell { /* Empty cells (the best is to hide them) */
  visibility: hidden;
}

.calendar tbody .emptyrow { /* Empty row (some months need less than 6 rows) */
  display: none;
}

/* The footer part -- status bar and "Close" button */

.calendar tfoot .footrow { /* The <TR> in footer (only one right now) */
}

.calendar tfoot .ttip { /* Tooltip (status bar) cell <TD> */
  background: #f4f0e8;
  padding: 1px;
  border: 1px solid #000;
  background: #848078;
  color: #fff;
  text-align: center;
}

.calendar tfoot .hilite { /* Hover style for buttons in footer */
  border-top: 1px solid #fff;
  border-right: 1px solid #000;
  border-bottom: 1px solid #000;
  border-left: 1px solid #fff;
  padding: 1px;
  background: #e4e0d8;
}

.calendar tfoot .active { /* Active (pressed) style for buttons in footer */
  padding: 2px 0px 0px 2px;
  border-top: 1px solid #000;
  border-right: 1px solid #fff;
  border-bottom: 1px solid #fff;
  border-left: 1px solid #000;
}

/* Combo boxes (menus that display months/years for direct selection) */

.combo {
  position: absolute;
  display: none;
  width: 4em;
  top: 0px;
  left: 0px;
  cursor: default;
  border-top: 1px solid #fff;
  border-right: 1px solid #000;
  border-bottom: 1px solid #000;
  border-left: 1px solid #fff;
  background: #e4e0d8;
  font-size: smaller;
  padding: 1px;
}

.combo .label,
.combo .label-IEfix {
  text-align: center;
  padding: 1px;
}

.combo .label-IEfix {
  width: 4em;
}

.combo .active {
  background: #c4c0b8;
  padding: 0px;
  border-top: 1px solid #000;
  border-right: 1px solid #fff;
  border-bottom: 1px solid #fff;
  border-left: 1px solid #000;
}

.combo .hilite {
  background: #048;
  color: #fea;
}

.calendar td.time {
  border-top: 1px solid #000;
  padding: 1px 0px;
  text-align: center;
  BACKGROUND-COLOR: #f4f0e8;
}

.calendar td.time .hour,
.calendar td.time .minute,
.calendar td.time .ampm {
  padding: 0px 3px 0px 4px;
  border: 1px solid #889;
  font-weight: bold;
  BACKGROUND-COLOR: #fff;
}

.calendar td.time .ampm {
  text-align: center;
}

.calendar td.time .colon {
  padding: 0px 2px 0px 3px;
  font-weight: bold;
}

.calendar td.time span.hilite {
  border-color: #000;
  BACKGROUND-COLOR: #766;
  color: #fff;
}

.calendar td.time span.active {
  border-color: #f00;
  BACKGROUND-COLOR: #000;
  color: #0f0;
} 

